==> tutti-ui-swing-1.0.2-sources.jar: fr/ifremer/tutti/ui/swing/content/protocol/CancelEditProtocolAction.java <==
package fr.ifremer.tutti.ui.swing.content.protocol;

/*
 * #%L
 * Tutti :: UI
 * $Id: CancelEditProtocolAction.java 512 2013-03-01 20:37:07Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0.2/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/protocol/CancelEditProtocolAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.TuttiScreen;
import fr.ifremer.tutti.ui.swing.util.action.AbstractTuttiAction;

import static org.nuiton.i18n.I18n._;

/**
 * Cancels the edition of a protocol
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class CancelEditProtocolAction extends AbstractTuttiAction<EditProtocolUIModel, EditProtocolUI, EditProtocolUIHandler> {

    public CancelEditProtocolAction(EditProtocolUIHandler handler) {
        super(handler,
              "cancel",
              _("tutti.action.cancel.editProtocol"),
              _("tutti.action.cancel.editProtocol.tip"),
              true
        );
    }

    @Override
    protected void doAction() {

        getContext().setScreen(TuttiScreen.SELECT_CRUISE);
    }

}

==> tutti-ui-swing-1.0.3-sources.jar: fr/ifremer/tutti/ui/swing/content/protocol/CancelEditProtocolAction.java <==
package fr.ifremer.tutti.ui.swing.content.protocol;

/*
 * #%L
 * Tutti :: UI
 * $Id: CancelEditProtocolAction.java 572 2013-03-11 10:01:36Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0.3/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/protocol/CancelEditProtocolAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.TuttiScreen;
import fr.ifremer.tutti.ui.swing.content.AbstractChangeScreenAction;
import fr.ifremer.tutti.ui.swing.content.MainUIHandler;

/**
 * Cancels the edition of a protocol
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class CancelEditProtocolAction extends AbstractChangeScreenAction {

    public CancelEditProtocolAction(MainUIHandler handler) {
        super(handler, true, TuttiScreen.SELECT_CRUISE);
        setSkipCheckCurrentScreen(true);
    }

}
